# README #

This repository was developed for Lauren Yu's honors thesis at Williams College. The goal of this thesis is to use machine learning to train a computer to take violin/viola music as input, and give bow position, distance from the bridge, and whether or not the bow leaves the string as outputs.

## Directories ##

* **data** contains `.arff` files.
* **feature_lists** contains text files with attributes for `.arff` files. There are all very similar, except they have different numbers of previous labels or include features of the next note. Also, some are for classification (i.e., for predicting `off-the-string`) as opposed to regression (predicting `distance-from-bridge` or `bow-position`).
* **scripts** has relevant code (see explanation below).
* **xml** contains the labeled MusicXML pieces (including predictions).

## Naming Scheme ##

In the data and xml folders, there are some abbreviations after the names of the files.

* `{0, 1, 2}` indicates bow position, distance from bridge, or off the string (in that order)
* `{4, 8, 16}p` indicates the number of previous labels.
* `b` indicates the use of bagging.
* `t` indicates training on one of the Bach pieces and testing on the other
* `n` indicates incorporating the next note.

## Scripts ##

Used for parsing MusicXML:

* `parser.py`
* `beatstrength.py`
* `pitchfunc.py`
* `instance.py`

Used for creating data files:

* `xml2arff.py`

Used for post-processing:

* `add_next_note.py`
* `discretize1.py`
* `normalize_duration.py`

Used for mapping predictions back to MusicXML:

* `predictions2xml.py`

